
:mod:`numina.core.pipeline` --- Pipeline classes
==================================================

.. automodule:: numina.core.pipeline
   :members:

:mod:`numina.core.pipelineload` --- Build pipelines from files
===============================================================

.. automodule:: numina.core.pipelineload
   :members:
